==> gstore-0.6.5.crate: gstore-0.6.5/src/store/widgets.rs <==
use glib::ObjectExt;
use libadwaita as adw;

/// Sending Actions from GTK widgets via dispatch() performs some checks for
/// prohibiting internal update loops.
pub trait DispatchWidget: glib::IsA<gtk::Widget> {
    fn dispatch(&self, action: &str, argument: Option<&dyn glib::ToVariant>) {
        crate::check_internal!(self);
        gtk::prelude::WidgetExt::activate_action(
            self,
            &format!("app.{}", action),
            argument.map(|a| a.to_variant()).as_ref(),
        );
    }
}

impl DispatchWidget for gtk::AppChooser {}
impl DispatchWidget for gtk::AppChooserButton {}
impl DispatchWidget for gtk::ApplicationWindow {}
impl DispatchWidget for gtk::Box {}
impl DispatchWidget for gtk::Button {}
impl DispatchWidget for gtk::Calendar {}
impl DispatchWidget for gtk::CenterBox {}
impl DispatchWidget for gtk::ColorButton {}
impl DispatchWidget for gtk::ComboBox {}
impl DispatchWidget for gtk::Dialog {}
impl DispatchWidget for gtk::DragIcon {}
impl DispatchWidget for gtk::DrawingArea {}
impl DispatchWidget for gtk::DropDown {}
impl DispatchWidget for gtk::Editable {}
impl DispatchWidget for gtk::EmojiChooser {}
impl DispatchWidget for gtk::Entry {}
impl DispatchWidget for gtk::Expander {}
impl DispatchWidget for gtk::Fixed {}
impl DispatchWidget for gtk::FlowBox {}
impl DispatchWidget for gtk::FontButton {}
impl DispatchWidget for gtk::Frame {}
impl DispatchWidget for gtk::Grid {}
impl DispatchWidget for gtk::GridView {}
impl DispatchWidget for gtk::HeaderBar {}
impl DispatchWidget for gtk::IconView {}
impl DispatchWidget for gtk::Image {}
impl DispatchWidget for gtk::InfoBar {}
impl DispatchWidget for gtk::Label {}
impl DispatchWidget for gtk::LevelBar {}
impl DispatchWidget for gtk::LinkButton {}
impl DispatchWidget for gtk::ListBox {}
impl DispatchWidget for gtk::ListBoxRow {}
impl DispatchWidget for gtk::LockButton {}
impl DispatchWidget for gtk::MenuButton {}
impl DispatchWidget for gtk::MessageDialog {}
impl DispatchWidget for gtk::Notebook {}
impl DispatchWidget for gtk::PasswordEntry {}
impl DispatchWidget for gtk::Popover {}
impl DispatchWidget for gtk::PopoverMenu {}
impl DispatchWidget for gtk::Revealer {}
impl DispatchWidget for gtk::ScrolledWindow {}
impl DispatchWidget for gtk::SearchBar {}
impl DispatchWidget for gtk::SearchEntry {}
impl DispatchWidget for gtk::SpinButton {}
impl DispatchWidget for gtk::Spinner {}
impl DispatchWidget for gtk::Stack {}
impl DispatchWidget for gtk::StackSidebar {}
impl DispatchWidget for gtk::StackSwitcher {}
impl DispatchWidget for gtk::Statusbar {}
impl DispatchWidget for gtk::Switch {}
impl DispatchWidget for gtk::Text {}
impl DispatchWidget for gtk::ToggleButton {}
impl DispatchWidget for gtk::Widget {}
impl DispatchWidget for gtk::Window {}

impl DispatchWidget for adw::ActionRow {}
impl DispatchWidget for adw::Carousel {}
impl DispatchWidget for adw::Clamp {}
impl DispatchWidget for adw::ComboRow {}
impl DispatchWidget for adw::ExpanderRow {}
impl DispatchWidget for adw::Flap {}
impl DispatchWidget for adw::HeaderBar {}
impl DispatchWidget for adw::Leaflet {}
impl DispatchWidget for adw::PreferencesGroup {}
impl DispatchWidget for adw::PreferencesRow {}
impl DispatchWidget for adw::SplitButton {}
impl DispatchWidget for adw::Squeezer {}
impl DispatchWidget for adw::Swipeable {}
impl DispatchWidget for adw::TabBar {}
impl DispatchWidget for adw::ViewStack {}
impl DispatchWidget for adw::ViewSwitcher {}
impl DispatchWidget for adw::ViewSwitcherBar {}

==> gstore-0.6.6.crate: gstore-0.6.6/src/store/widgets.rs <==
#[cfg(feature = "libadwaita")]
use glib::ObjectExt;
#[cfg(feature = "libadwaita")]
use libadwaita as adw;

/// Sending Actions from GTK widgets via dispatch() performs some checks for
/// prohibiting internal update loops.
#[cfg(feature = "gtk")]
pub trait DispatchWidget: glib::IsA<gtk::Widget> {
    fn dispatch(&self, action: &str, argument: Option<&dyn glib::ToVariant>) {
        crate::check_internal!(self);
        gtk::prelude::WidgetExt::activate_action(
            self,
            &format!("app.{}", action),
            argument.map(|a| a.to_variant()).as_ref(),
        );
    }
}

#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::AppChooser {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::AppChooserButton {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::ApplicationWindow {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Box {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Button {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Calendar {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::CenterBox {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::ColorButton {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::ComboBox {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Dialog {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::DragIcon {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::DrawingArea {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::DropDown {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Editable {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::EmojiChooser {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Entry {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Expander {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Fixed {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::FlowBox {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::FontButton {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Frame {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Grid {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::GridView {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::HeaderBar {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::IconView {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Image {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::InfoBar {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Label {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::LevelBar {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::LinkButton {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::ListBox {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::ListBoxRow {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::LockButton {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::MenuButton {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::MessageDialog {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Notebook {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::PasswordEntry {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Popover {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::PopoverMenu {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Revealer {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::ScrolledWindow {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::SearchBar {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::SearchEntry {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::SpinButton {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Spinner {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Stack {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::StackSidebar {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::StackSwitcher {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Statusbar {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Switch {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Text {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::ToggleButton {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Widget {}
#[cfg(feature = "gtk")]
impl DispatchWidget for gtk::Window {}

#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::ActionRow {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::Carousel {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::Clamp {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::ComboRow {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::ExpanderRow {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::Flap {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::HeaderBar {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::Leaflet {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::PreferencesGroup {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::PreferencesRow {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::SplitButton {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::Squeezer {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::Swipeable {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::TabBar {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::ViewStack {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::ViewSwitcher {}
#[cfg(feature = "libadwaita")]
impl DispatchWidget for adw::ViewSwitcherBar {}
